@@ -3,3 +3,5 @@ from .utils import concat
 from .expression import Expression  # to pass a custom Expression object in Table.filter or Column.filter
 
 __all__ = ['Database', 'concat', 'Expression']
+__version__ = '2.0.4'
+__author__ = 'Shneor Elmaleh'
