@@ -4,14 +4,16 @@ from pandas import DataFrame, Series
 
 import sqlite3
 import itertools
-from typing import Generator, Callable, Any, Sequence, TypeVar, Iterable, overload
+from typing import Generator, Callable, Any, Sequence, TypeVar, Iterable, overload, TYPE_CHECKING
 
 from .expression import Expression
 from .cache import Cache
 from .utils import create_temp_view, get_random_name, sql_tuple, convert_type_to_sql
 
-ColumnValue = str | int | float | bool | None
-Numeric = int | float
+if TYPE_CHECKING:
+    ColumnValue = str | int | float | bool | None
+    Numeric = int | float
+
 T = TypeVar('T')
 ROWID = '_rowid_ AS _rowid_'  # select rowid/oid/_rowid_ as _rowid_
 
