@@ -3,7 +3,7 @@ from __future__ import annotations
 from pandas import DataFrame
 
 import sqlite3
-from typing import Generator, Callable, Any, overload, Literal
+from typing import Generator, Callable, Any, overload, Literal, TYPE_CHECKING
 
 from .exceptions import InvalidColumnError
 from .column import Column
@@ -11,8 +11,10 @@ from .cache import Cache
 from .expression import Expression
 from .utils import create_temp_view, get_random_name, sql_tuple
 
-PrimitiveTypes = str | int | float | bool | None
-TableRow = tuple[PrimitiveTypes, ...]
+if TYPE_CHECKING:
+    PrimitiveTypes = str | int | float | bool | None
+    TableRow = tuple[PrimitiveTypes, ...]
+
 ROWID = '_rowid_ AS _rowid_'  # select rowid/oid/_rowid_ as _rowid_
 
 
